==> haskell-pandoc-types-1.22-102-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-types
version:              1.22
visibility:           public
id:                   pandoc-types-1.22-58McfLPuEYkIVVBZ4suXjF
key:                  pandoc-types-1.22-58McfLPuEYkIVVBZ4suXjF
license:              BSD-3-Clause
copyright:            (c) 2006-2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://pandoc.org/
synopsis:             Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.

    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.

    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.

    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.

    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.

category:             Text
abi:                  3711a1404292632fa4915fc3c86a38dc
exposed:              True
exposed-modules:
    Text.Pandoc.Arbitrary Text.Pandoc.Builder Text.Pandoc.Definition
    Text.Pandoc.Generic Text.Pandoc.JSON Text.Pandoc.Walk

hidden-modules:       Paths_pandoc_types
import-dirs:          /usr/lib/ghc-9.0.1/site-local/pandoc-types-1.22
library-dirs:         /usr/lib/ghc-9.0.1/site-local/pandoc-types-1.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/pandoc-types-1.22
hs-libraries:         HSpandoc-types-1.22-58McfLPuEYkIVVBZ4suXjF
depends:
    QuickCheck-2.14.2-IrhINHdHXv9CDSLhYN7ABW
    aeson-1.5.6.0-nrMp0b6teF7D3JqNhCf9o base-4.15.0.0
    bytestring-0.10.12.1 containers-0.6.4.1 deepseq-1.4.5.0
    ghc-prim-0.7.0 syb-0.7.2.1-3ORM9hCNu8V5barlF73jrL text-1.2.4.1
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-types-1.22-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-types
version:              1.22
visibility:           public
id:                   pandoc-types-1.22-DlUIuOPhLfBTOu7knq4CE
key:                  pandoc-types-1.22-DlUIuOPhLfBTOu7knq4CE
license:              BSD-3-Clause
copyright:            (c) 2006-2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://pandoc.org/
synopsis:             Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.

    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.

    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.

    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.

    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.

category:             Text
abi:                  45a0e6fe894bf2f734a0f3b4334cc9a8
exposed:              True
exposed-modules:
    Text.Pandoc.Arbitrary Text.Pandoc.Builder Text.Pandoc.Definition
    Text.Pandoc.Generic Text.Pandoc.JSON Text.Pandoc.Walk

hidden-modules:       Paths_pandoc_types
import-dirs:          /usr/lib/ghc-9.0.1/site-local/pandoc-types-1.22
library-dirs:         /usr/lib/ghc-9.0.1/site-local/pandoc-types-1.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/pandoc-types-1.22
hs-libraries:         HSpandoc-types-1.22-DlUIuOPhLfBTOu7knq4CE
depends:
    QuickCheck-2.14.2-JiWzfNqvdmcIR4KVQ9LtVR
    aeson-1.5.6.0-HjRPlMbeXBZ4yuplu15455 base-4.15.0.0
    bytestring-0.10.12.1 containers-0.6.4.1 deepseq-1.4.5.0
    ghc-prim-0.7.0 syb-0.7.2.1-JJZ7ElOKhr6qvmtx8wPbK text-1.2.4.1
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
